@@ -1,7 +1,10 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Network.IRC.Bot.Part.Hello where
 
 import Control.Monad.Trans      (liftIO)
 import Data.Maybe               (fromMaybe)
+import Data.ByteString          (ByteString)
+import Data.Monoid              ((<>))
 import Network.IRC.Bot.Log      (LogLevel(Debug))
 import Network.IRC.Bot.BotMonad (BotMonad(..), maybeZero)
 import Network.IRC.Bot.Commands (PrivMsg(..),askSenderNickName, replyTo, sendCommand)
@@ -12,15 +15,15 @@ import Text.Parsec              (ParsecT, (<|>), string, try)
 helloPart :: (BotMonad m) => m ()
 helloPart = parsecPart helloCommand
 
-helloCommand :: (BotMonad m) => ParsecT String () m ()
+helloCommand :: (BotMonad m) => ParsecT ByteString () m ()
 helloCommand =
     do try $ botPrefix >> string "hello"
        logM Debug "helloPart"
        target <- maybeZero =<< replyTo
-       logM Debug $ "target: " ++ target
+       logM Debug $ "target: " <> target
        mNick <- askSenderNickName
        let greetings = ["Hello", "Howdy", "Greetings", "Word up"]
        n <- liftIO $ randomRIO (0, length greetings - 1)
-       let msg = greetings!!n ++ ", " ++ (fromMaybe "stranger" mNick)
+       let msg = greetings!!n <> ", " <> (fromMaybe "stranger" mNick)
        sendCommand (PrivMsg Nothing [target] msg)
     <|> return ()
